@@ -25,16 +25,16 @@ log = logging.getLogger(__name__)
 
 
 class TCPIntermediate(TCP):
-    def __init__(self):
-        super().__init__()
+    def __init__(self, proxy: type):
+        super().__init__(proxy)
         self.is_first_packet = None
 
     def connect(self, address: tuple):
         super().connect(address)
         self.is_first_packet = True
-        log.info("Connected!")
+        log.info("Connected{}!".format(" with proxy" if self.proxy_enabled else ""))
 
-    def send(self, data: bytes):
+    def sendall(self, data: bytes, *args):
         length = len(data)
         data = pack("<i", length) + data
 
@@ -44,12 +44,10 @@ class TCPIntermediate(TCP):
 
         super().sendall(data)
 
-    def recv(self) -> bytes or None:
-        length = self.recvall(4)
+    def recvall(self, length: int = 0) -> bytes or None:
+        length = super().recvall(4)
 
         if length is None:
             return None
 
-        packet = self.recvall(unpack("<I", length)[0])
-
-        return packet
+        return super().recvall(unpack("<I", length)[0])
